#!/usr/bin/env python

#
#  Copyright (c) 2013 Dell, Inc.
#  by Praveen K Paladugu <praveen_paladugu@dell.com>
#  Licensed under the GNU General Public license, version 2 or higher.
#

""" Class for parsing the conf file  and the default settings """

import ConfigParser
import logging
import io
import string
import os
import gettext 

gettext.textdomain('dell_app_init')
_ = lambda x: gettext.ldgettext("dell_app_init", x)

default_config = """
[DEFAULT]
DISPLAY = :9
VT = vt7
app_log = /var/log/startup_app.log
xorg_log = /var/log/startup_xorg.log
wm_log = /var/log/startup_wm.log 
eula_state = /var/lib/dell_app_init/eula_state
"""

class App_Conf_Parser:

    app_config = 0
    parser_logger = 0

    def __init__ (self, filenames):
	""" Set the confi_parser to the input filenames"""

	## Set the Logger.
	self.parser_logger = logging.getLogger("startup_app.parser_log")
        #Logger is configured after the parsing is complete. So use pirnt here. 
        print _("filenames provided to the parser = "), filenames


	# Read all default values first.
	self.app_config = ConfigParser.ConfigParser()
	self.app_config.readfp(io.BytesIO(default_config))
	
	## Read all the filenames passed.
	self.app_config.read(filenames)
	
	return


    def get_conf_val (self, section, variable):
	""" Given a Section and Variable name return the value from the parsed information"""
	val = 0 

        try:
	    val = self.app_config.get(section,variable)
	except ConfigParser.NoOptionError :
	    self.parser_logger.debug( _("Returned empty string for section= %(sec)s, variable= %(var)s") %{"sec":section, "var":variable})
	    return ""

	else:
	    self.parser_logger.debug ( _("For section= %(sec)s, variable=%(var)s returned value= %(val)s") %{"sec": section, "var":variable, "val":val} )
	    val = val.replace('\'','' )
	    val = val.replace('"','' )
	    val = val.strip()
	    return val


    def get_eula_version_from_file (self,filename):
    # Function will be used in multiple programs, so saving it here.
	if (filename == ''):
            return -1

	if (not os.path.exists(filename)):
	    return -1

	fd = open(filename, 'r')
	if fd:
	    v_lines = fd.readlines()
	    fd.close()
	else:
	    # if file doesn't exist return -1
	    return -1

	for line in v_lines:
	    if line[:1] == '#':
		continue
	    else:
		# Just return the first non-commented line
		return line

	    # Return 0, if no valid version info is available
	return 0

    def get_eula_text_filename (self):
    # If the EULA text in the right languages are available, that filename wil be returned. If not, the setting from the conf file will be returned. 

	filename = self.get_conf_val("app_conf", "eula_text_filename")
	lang = os.getenv("LANG")
	if (lang is "") or (lang is None) :
                lang = 'en_US.UTF-8'

	# Chop off the UTF-8 encoding part
	lang = lang.split('.')[0]
	# Chop off the country code
	langBase = lang.split('_')[0]
	
	if ( os.path.exists(filename+'.'+lang) ):
	    #return eula_text.es_ES if exists	
	    return filename+'.'+lang

	elif (os.path.exists(filename+'.'+langBase) ):
	    #return eula_text.es if exists	
	    return filename+'.'+langBase
	else:
	    # return the base filename, if lang specific files don't exist
	    return filename
	
	
	
