#!/usr/bin/env python
#
#  Copyright (c) 2013 Dell, Inc.
#  by Praveen K Paladugu <praveen_paladugu@dell.com>
#  Licensed under the GNU General Public license, version 2 or higher.
#


""" Class for the EULA Text Box"""

import sys, os
import logging
import App_Conf_Parser
import gettext

gettext.textdomain('dell_app_init')
_ = lambda x: gettext.ldgettext("dell_app_init", x)

## X server should be up by now. So, the following import should be fine
try:
    import gtk
    import gtk.glade
except:
    print "Gtk/Glade is not installed."
    sys.exit(1)


eulabox_glade_path="/usr/share/dell_app_init/EulaBox.glade"

class EulaBox:

    conf_parser = 0
    eula_tree = 0
    eula_window = 0
    eula_dialog = 0
    logger = 0
    eula_accepted = 0


    def __init__(self, filename, parser):
        """ Initialize the EulaBox with the given filename """

	self.logger = logging.getLogger("startup_app.EulaBox")

	# Capture the parser object.
	self.conf_parser = parser

	self.eula_accepted = 0
	self.eula_tree = gtk.glade.XML(eulabox_glade_path)
	self.eula_tree.signal_autoconnect(self)

	self.logger.debug (_("EulaBox's glade path = %s"), eulabox_glade_path)

	self.eula_window = self.eula_tree.get_widget("License Agreement")
	self.eula_window.connect("destroy",self.on_destroy_event)
        self.eula_window.connect("delete_event",self.on_delete_event)


	eula_textbox = self.eula_tree.get_widget("EulaTextBox")
	self.eula_dialog = self.eula_tree.get_widget ("AcceptRejectDialog")

	self.logger.debug(_("Eula's text filename = %s "),filename)
	fp = open (filename)
	#Negative parameter reads to the end of the file
	eula_text = fp.read(-1)
	fp.close()

	# Populate the buffer and set to text box's buffer
	text_buffer = gtk.TextBuffer()
	text_buffer.set_text(eula_text)
	eula_textbox.set_buffer(text_buffer)

        return

    def is_radio_license_accepted(self):
	agree_radio = self.eula_tree.get_widget("LicenseAgree_radio")
	return agree_radio.get_active()


    def on_Forward_clicked (self, widget):

	if (not self.is_radio_license_accepted()):
	    # If License Not accepted, show the eula Dialog.
	    self.eula_window.hide_all()
	    self.eula_dialog.show_all()
	else:
	    self.save_eula_state()
	    self.eula_accepted = 1
	    self.close_eula_and_return()

    	return

    def save_eula_state(self):

	eula_state = self.conf_parser.get_conf_val ("app_conf", "eula_state")
	if (eula_state == "" ):
            ##Use the default setting
	    eula_state = self.conf_parser.get_conf_val("DEFAULT", "eula_state")

	eula_input = self.conf_parser.get_conf_val ("app_conf","eula_input_version_file")
	
	installed_version = self.conf_parser.get_eula_version_from_file (eula_input) 

	if (installed_version == -1 ):
	    # Either the eula_input file is not present or empty, capture the installed version as 0
	    installed_version = "0.0"

	dir_name = os.path.dirname(eula_state)	
	if not  os.path.exists(dir_name):
	    os.makedirs(dir_name, 0744)	

	fd = open(eula_state, 'w')
	if fd:
    	    fd.write (str(installed_version))
	    fd.close
	else:
	    self.logger.error(_("Not able to open the file to save EULA state"))	    

	return


    def is_eula_accepted(self):
	## Return the saved state of eula_accepted variable.
	if (self.eula_accepted):
	    return 1
	else:
	    return 0
	

    def close_eula_and_return(self):
    
        self.eula_window.hide_all()
        self.eula_dialog.hide_all()
        gtk.main_quit()

	return
	
    def on_destroy_event (self, widget):
	# Ignore destroy event
	return

    def on_delete_event (self, widget,data):
	# Ignore the delete event
        return True


	
    def on_dialog_Yes_clicked(self, widget):
#	self.logger.info(_("The services listed in the conf file will disabled."))

#	services = self.conf_parser.get_conf_val("app_conf", "services")
#	if (services == ''):


	#As the program state has to be cleaned up, will return to the main function to cleanup and shutdown the appliance. 
	self.logger.info(_("As EULA is not accepted, the appliance will be shutdown."))


#	else:
#	    services_split = services.split(',')
#	    for service in services_split:
#		self.logger.info (_("Stopping service: %s"), service)
#		ser_cmd = "service "+service+" stop"
#		ret_val=os.system(ser_cmd)
#		if (ret_val):
#		    self.logger.error(_("Failed while stopping %s service"), service)
#		else:
#		    self.logger.info (_("Service %s stopped successfully"), service)

	self.eula_accepted = 0
	self.close_eula_and_return()
	return


    def on_dialog_No_clicked (self, widget):
	self.eula_dialog.hide_all()
	self.eula_window.show_all()
	return
