#!/usr/bin/env python
#
#  Copyright (c) 2013 Dell, Inc.
#  by Praveen K Paladugu <praveen_paladugu@dell.com>
#  Licensed under the GNU General Public license, version 2 or higher.
#


import logging
import os, sys
import subprocess
import App_Conf_Parser
import gettext

gettext.textdomain('dell_app_init')
_ = lambda x: gettext.ldgettext("dell_app_init", x)

## X server should be up by now. So, the following import should be fine
try:
    import gtk
    import gtk.glade
except:
    print "Gtk/Glade is not installed."
    sys.exit(1)

gtk.glade.bindtextdomain('dell_app_init','/usr/share/locale')
gtk.glade.textdomain('dell_app_init')



class Startup_Interface:

#Global vars in this class	
    topWindow = 0
    logger = 0
    EmptyWindow = 0
    EulaDisplayWindow =0
    EulaTextView = 0
    parser = 0

##TODO: Erorr out on GUI, if any of class imports fails.
##TODO: Where ever necessary, add debug logs

    def on_DateWindow_clicked(self, widget):
	""" Handler function to configure Date & Time """
	
	if not "/usr/share/system-config-date" in sys.path:
	    sys.path.append("/usr/share/system-config-date")

	self.topWindow.hide()
	import scdMainWindow
	scdWindow = scdMainWindow.scdMainWindow(0)
	scdWindow.win.set_type_hint(gtk.gdk.WINDOW_TYPE_HINT_MENU)
	scdWindow.closeParent = False
	scdWindow.stand_alone()

	scdWindow.win.hide()
	self.topWindow.show_all()
	return

    def on_EulaDisplayWindow_destroy_event (self, widget, data=None ):
	""" Destroy the EULA display and get back to Main Window """
        self.EulaDisplayWindow.hide_all()
        self.topWindow.show_all()
	
	return
    
    def on_EulaDisplayWindow_delete_event (self, widget, event, data=None):
	""" Closed the EULA Text Window with Alt-F4 """
        self.EulaDisplayWindow.hide_all()
        self.topWindow.show_all()
	
	# if set to False, the topWindow is also closed, which causes the program to mis-behave.
	return True
    
    def on_EULAText_clicked(self, widget):
	""" Handler for EULA Text Button. Show the EULA Text for customers to review """

	eula_text_filename = self.parser.get_eula_text_filename()
	self.logger.debug(_("filename of the EULA file = %s"), eula_text_filename)

	if ( eula_text_filename ) and os.access (eula_text_filename, os.R_OK):
	    # Open the file and read the text to a buffer. 
	    fp = open (eula_text_filename)
	    eula_text = fp.read(-1)
	    fp.close()
	
	    #Populate a TextBuffer and assign it the EulaDisplayWindow
	    eula_text_buffer = gtk.TextBuffer()
	    eula_text_buffer.set_text(eula_text)
	    self.EulaTextView.set_buffer(eula_text_buffer)
	    
	else:
	    #TODO: Throw an Error when the EULA file is not available.
	    #dell_app_init should fail if the file doesn't exist. But better to check here as well.
	    pass

	self.topWindow.hide_all()
	self.EulaDisplayWindow.show_all()
	return

    def on_EulaTextClose_clicked (self, widget):
	""" Close the EULA Text Display Window and redisplay the TopWindow"""
	
	self.EulaDisplayWindow.hide_all()
	self.topWindow.show_all()
	return

    def on_Language_clicked(self, widget):
	"""Handler function to configure Language"""

	if not "/usr/share/system-config-language" in sys.path:
	    sys.path.append("/usr/share/system-config-language")

	self.set_supported_languages()

	self.topWindow.hide()
	import language_gui
	app = language_gui.childWindow()
	#app.mainWindow.set_type_hint(gtk.gdk.WINDOW_TYPE_HINT_MENU)
	app.stand_alone()

	app.mainWindow.hide()
	self.topWindow.show_all()
	#TODO: Capture the language that is selected
	return
    
    def	set_supported_languages(self):
	""" Function to set the supported language setting in /etc/locale.conf file"""
	locale_conf_file = '/etc/sysconfig/i18n'	

	if (not os.path.exists(locale_conf_file) ):
	    locale_fd = open( locale_conf_file, 'w')
	    setting = "SUPPORTED=" + self.parser.get_conf_val ("app_conf", "supported_languages")
	    locale_fd.write(setting)
	    locale_fd.write("\n")
            #Set a default LANG setting as well.
            setting ='LANG="en_US.UTF-8"'
            locale_fd.write(setting)
	    locale_fd.write("\n")

	    locale_fd.close ()

	else:
	    ## If the locale exists, read all lines
	    locale_fd = open( locale_conf_file, 'r')
	    if locale_fd:
		loc_lines = locale_fd.readlines()
		locale_fd.close()

	    ## Write back the lines just replacing the value of SUPPORTED variable.
	    locale_fd_wr = open( locale_conf_file, 'w')
	    supported_found=0
            lang_setting_found=0

	    for line in loc_lines:
		if line[:10] == 'SUPPORTED=':
		    self.logger.debug (_('Replacing the value of SUPPORTED in locale conf file'))
		    setting = "SUPPORTED=" + self.parser.get_conf_val ("app_conf", "supported_languages")
		    locale_fd_wr.write( setting)
		    locale_fd_wr.write("\n")
		    supported_found = 1
                elif line[:5] == "LANG=":
                    lang_setting_found=1
		    locale_fd_wr.write(line)
		    locale_fd_wr.write("\n")
                elif line[:9] == "LANGUAGE=":
                    lang_setting_found=1
		    locale_fd_wr.write(line)
		    locale_fd_wr.write("\n")
                elif line == "\n":
		    pass
		else:
		    locale_fd_wr.write(line)
		    locale_fd_wr.write("\n")
	   
 
	    if (supported_found == 0 ):
		# SUPPORTED setting not found it locale file, add a new one.
		setting = "SUPPORTED=" + self.parser.get_conf_val ("app_conf", "supported_languages")
                locale_fd_wr.write( setting)
                locale_fd_wr.write("\n")

	    if (lang_setting_found == 0):
		# A LANG setting should be present for system-config-language to update it. So, make sure a default LANG settig is present in the i18n file.
		setting ='LANG="en_US.UTF-8"'
		locale_fd_wr.write( setting)
		locale_fd_wr.write("\n")

	    locale_fd_wr.close()

	return


    def on_Network_clicked (self, widget):
	"""Handler for Network Settings"""

	self.topWindow.hide_all()
##	Using the Empty Window as a workaround. Seems like Gtk doesn't allow all the windows to be hidden.
	self.EmptyWindow.show_all()   
	os.system("/usr/bin/nm-connection-editor")
##	TODO: Error out, if nm-connection-editor is not present
	os.system("service network restart > /dev/null")
	self.EmptyWindow.hide_all()   
	self.topWindow.show_all()
	return



    def on_Keyboard_clicked(self, widget):
	""" Handler for keyboard Settings """

        if not "/usr/share/system-config-keyboard" in sys.path:
	    sys.path.append("/usr/share/system-config-keyboard")

	self.topWindow.hide()
	import keyboard_gui
	app = keyboard_gui.childWindow()
	app.stand_alone()
	self.topWindow.show_all()
	return



#    def on_UsersButton_clicked(self, widget):
#	"""Handler for the User & Password Button"""
#
#        if not "/usr/share/system-config-users" in sys.path:
#	    sys.path.append("/usr/share/system-config-users")
#
#	self.topWindow.hide()
#	import mainWindow
#	reload(mainWindow)
#	user_win=mainWindow.mainWindow()
#	user_win.toplevel.hide()	
#	self.topWindow.show_all()
#	return



    def on_Close_clicked(self, widget):
	"""Handler for the Close button"""

	self.topWindow.hide_all()
	gtk.main_quit()
	return



    def on_TopWindow_destroy(self, widget):
	""" destory Top window"""

	self.topWindow.hide()
	gtk.main_quit()
	return
	
    def on_TopWindow_delete(self, widget, event, data=None):
	""" Close the window with Alt-F4"""

	self.topWindow.hide_all()
	gtk.main_quit()
	#returning False will cause the window to be closed.
	return False
	

    def destroy_cb(self, widget):
	""" Callback function to hide the main window and then terminate. """

	self.topWindow.hide_all()
	gtk.main_quit()
	return



    def __init__(self, parser):
	""" Import the glade file and connect the signal handlers"""
    
	self.logger = logging.getLogger("startup_app.mainWindow")

	self.parser = parser
	startup_glade_path = "/usr/share/dell_app_init/Startup_Interface.glade"
	self.logger.debug (_("Glade file of mainWindow = %s"), startup_glade_path)

	#Load the glade file
	topwindow_tree_xml = gtk.glade.XML(startup_glade_path,"TopWindow")

	#Connect the signal handlers
	topwindow_tree_xml.signal_autoconnect(self)
	self.topWindow = topwindow_tree_xml.get_widget("TopWindow")


	# No need to handle signals for the Empty Window. This is fine.
	# This is just a workaround. Gtk doesn't allow hiding all the windows, when another process is running. So using an empty Window.
	emptywindow_xml_tree = gtk.glade.XML(startup_glade_path, 'EmptyWindow' )
	self.EmptyWindow =  emptywindow_xml_tree.get_widget('EmptyWindow')
	self.EmptyWindow.hide_all()


	# Import EULA Text Window, and connect the handlers
	euladisplay_xml_tree = gtk.glade.XML(startup_glade_path, 'EulaDisplayWindow')
	euladisplay_xml_tree.signal_autoconnect(self)
	self.EulaDisplayWindow = euladisplay_xml_tree.get_widget('EulaDisplayWindow')
	self.EulaTextView = euladisplay_xml_tree.get_widget('EulaDisplayText')
	self.EulaDisplayWindow.hide_all()
	
	return
